@@ -1,17 +1,27 @@
+"""
+Copyright (C) 2021 Clariteia SL
+
+This file is part of minos framework.
+
+Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
+"""
+
 import importlib
 import typing as t
 
 import six
 
-from minos.common.exceptions import MinosImportException
+from .exceptions import (
+    MinosImportException,
+)
 
 
 def import_module(module: str) -> t.Callable:
     """Import the given module from a package"""
     try:
-        if '.' in module:
-            parts = module.split('.')
-            name = '.'.join(parts[:-1])
+        if "." in module:
+            parts = module.split(".")
+            name = ".".join(parts[:-1])
 
         module_ref = importlib.import_module(name)
         kallable = getattr(module_ref, parts[-1])
